@@ -1,8 +1,7 @@
 package HTML::FormFu::Constraint::AutoSet;
 
-use strict;
-use base 'HTML::FormFu::Constraint::Set';
-use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Constraint::Set';
 
 sub process {
     my $self = shift;
@@ -11,7 +10,7 @@ sub process {
 
     $self->set( \@set );
 
-    return $self->next::method(@_);
+    return $self->SUPER::process(@_);
 }
 
 sub _parse_value {
@@ -25,6 +24,8 @@ sub _parse_value {
     }
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -55,3 +56,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
