@@ -1,11 +1,12 @@
 package HTML::FormFu::Constraint::Regex;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
 use Regexp::Common;
 
-__PACKAGE__->mk_accessors(qw/ regex common /);
+has common => ( is => 'rw', traits  => ['Chained'] );
+has regex  => ( is => 'rw', traits  => ['Chained'] );
 
 sub constrain_value {
     my ( $self, $value ) = @_;
@@ -13,11 +14,15 @@ sub constrain_value {
     return 1 if !defined $value || $value eq '';
 
     my $regex;
+
     if ( defined $self->regex ) {
         $regex = $self->regex;
     }
     elsif ( defined $self->common ) {
-        my @common = ref $self->common ? @{ $self->common } : ( $self->common );
+        my @common
+            = ref $self->common
+            ? @{ $self->common }
+            : $self->common;
 
         $regex = shift @common;
         $regex = $RE{$regex};
@@ -35,6 +40,8 @@ sub constrain_value {
     return $self->not ? !$ok : $ok;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -74,7 +81,7 @@ C<< $RE{URI}{HTTP}{-scheme => 'https?'} >>
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -87,3 +94,5 @@ Sebastian Riedel, C<sri@oook.de>.
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
