@@ -1,12 +1,11 @@
 package HTML::FormFu::Constraint::Set;
 
-use strict;
-use base 'HTML::FormFu::Constraint';
-use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
-use Storable qw( dclone );
+use Clone ();
 
-__PACKAGE__->mk_accessors(qw( set ));
+has set => ( is => 'rw', traits  => ['Chained'] );
 
 sub constrain_value {
     my ( $self, $value ) = @_;
@@ -23,15 +22,17 @@ sub constrain_value {
 sub clone {
     my $self = shift;
 
-    my $clone = $self->next::method(@_);
+    my $clone = $self->SUPER::clone(@_);
 
     if ( $self->set ) {
-        $clone->set( dclone $self->set );
+        $clone->set( Clone::clone( $self->set ) );
     }
 
     return $clone;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -69,3 +70,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
