@@ -1,14 +1,14 @@
 package HTML::FormFu::Deflator::CompoundDateTime;
 
-use strict;
-use base 'HTML::FormFu::Deflator';
+use Moose;
+extends 'HTML::FormFu::Deflator';
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use DateTime;
 use List::MoreUtils qw( none );
 use Carp qw( croak );
 
-__PACKAGE__->mk_accessors(qw( field_order ));
+has field_order => ( is => 'rw', traits  => ['Chained'] );
 
 my @known_fields = qw( year month day hour minute second nanosecond time_zone );
 
@@ -49,6 +49,8 @@ sub deflator {
     return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -110,7 +112,7 @@ By default, expects the field names to be any of the following:
 
 Arguments: \@order
 
-If your field names doesn't follow the convention listed above, you must 
+If your field names don't follow the convention listed above, you must 
 provide an arrayref containing the above names, in the order they correspond 
 with your own fields.
 
