@@ -1,36 +1,18 @@
 package HTML::FormFu::Filter;
+use Moose;
 
-use strict;
-use Class::C3;
+with 'HTML::FormFu::Role::NestedHashUtils',
+     'HTML::FormFu::Role::HasParent',
+     'HTML::FormFu::Role::Populate';
 
-use HTML::FormFu::Attribute qw( mk_item_accessors mk_accessors
-    mk_inherited_accessors );
+use HTML::FormFu::Attribute qw( mk_inherited_accessors );
 use HTML::FormFu::ObjectUtil qw(
-    populate form name parent nested_name nested_names get_nested_hash_value
-    set_nested_hash_value nested_hash_key_exists );
+    form name parent nested_name nested_names );
 use Carp qw( croak );
 
-__PACKAGE__->mk_item_accessors(qw( type ));
+has type => ( is => 'rw', traits  => ['Chained'] );
 
-__PACKAGE__->mk_accessors(qw( localize_args ));
-
-sub new {
-    my $class = shift;
-
-    my %attrs;
-    eval { %attrs = %{ $_[0] } if @_ };
-    croak "attributes argument must be a hashref" if $@;
-
-    my $self = bless {}, $class;
-
-    if ( exists $attrs{parent} ) {
-        $self->parent( delete $attrs{parent} );
-    }
-
-    $self->populate( \%attrs );
-
-    return $self;
-}
+has localize_args => ( is => 'rw', traits  => ['Chained'] );
 
 sub process {
     my ( $self, $result, $params ) = @_;
@@ -60,6 +42,8 @@ sub clone {
     return bless \%new, ref $self;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -118,6 +102,13 @@ to replace C<[_1]>, C<[_2]>, etc. in the localized string.
 Returns the L<HTML::FormFu::Element::_Field> object that the filter is 
 associated with.
 
+=head2 get_parent
+
+Arguments: \%options
+
+Traverses the parent hierarchy, returning the first parent that matches the
+supplied options.
+
 =head2 form
 
 Returns the L<HTML::FormFu> object that the filter's field is attached to.
@@ -164,6 +155,17 @@ Shorthand for C<< $filter->parent->name >>
 
 =back
 
+=head1 FILTER BASE CLASSES
+
+The following are base classes for other filters, and generally needn't be 
+used directly.
+
+=over
+
+=item L<HTML::FormFu::Filter::_Compound>
+
+=back
+
 =head1 AUTHOR
 
 Carl Franks, C<cfranks@cpan.org>
@@ -175,3 +177,5 @@ Sebastian Riedel.
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
