@@ -1,9 +1,9 @@
 package HTML::FormFu::Filter::Callback;
 
-use strict;
-use base 'HTML::FormFu::Filter';
+use Moose;
+extends 'HTML::FormFu::Filter';
 
-__PACKAGE__->mk_accessors(qw/callback/);
+has callback => ( is => 'rw', traits => ['Chained'] );
 
 sub filter {
     my ( $self, $value, $params ) = @_;
@@ -15,6 +15,8 @@ sub filter {
     return $callback->( $value, $params );
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
