@@ -1,7 +1,7 @@
 package HTML::FormFu::Filter::HTMLEscape;
 
-use strict;
-use base 'HTML::FormFu::Filter';
+use Moose;
+extends 'HTML::FormFu::Filter';
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -16,6 +16,8 @@ sub filter {
     return $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
