@@ -1,7 +1,7 @@
 package HTML::FormFu::Filter::LowerCase;
 
-use strict;
-use base 'HTML::FormFu::Filter';
+use Moose;
+extends 'HTML::FormFu::Filter';
 
 sub filter {
     my ( $self, $value ) = @_;
@@ -11,6 +11,8 @@ sub filter {
     return lc $value;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
