@@ -1,46 +1,14 @@
 package HTML::FormFu::Plugin;
+use Moose;
 
-use strict;
-use Class::C3;
+with 'HTML::FormFu::Role::HasParent',
+     'HTML::FormFu::Role::Populate';
 
-use HTML::FormFu::Attribute qw( mk_item_accessors mk_accessors );
-use HTML::FormFu::ObjectUtil qw( populate form parent );
+use HTML::FormFu::ObjectUtil qw( form parent );
 use Scalar::Util qw( refaddr reftype );
 use Carp qw( croak );
 
-use overload
-    'eq' => sub { refaddr $_[0] eq refaddr $_[1] },
-    '==' => sub { refaddr $_[0] eq refaddr $_[1] },
-    bool => sub {1},
-    fallback => 1;
-
-__PACKAGE__->mk_item_accessors(qw( type ));
-
-sub new {
-    my $class = shift;
-    my %attrs;
-    
-    if (@_) {
-        croak "attributes argument must be a hashref"
-            if reftype( $_[0] ) ne 'HASH';
-        
-        %attrs = %{ $_[0] };
-    }
-
-    my $self = bless {}, $class;
-
-    for (qw( type )) {
-        croak "$_ attribute required" if !exists $attrs{$_};
-    }
-
-    if ( exists $attrs{parent} ) {
-        $self->parent( delete $attrs{parent} );
-    }
-
-    $self->populate( \%attrs );
-
-    return $self;
-}
+has type => ( is => 'rw', traits  => ['Chained'] );
 
 sub pre_process { }
 
@@ -60,6 +28,8 @@ sub clone {
     return bless \%new, ref $self;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -127,3 +97,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
