@@ -1,8 +1,7 @@
 package HTML::FormFu::Plugin::StashValid;
 
-use strict;
-use base 'HTML::FormFu::Plugin';
-use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Plugin';
 
 sub post_process {
     my ($self) = @_;
@@ -17,6 +16,8 @@ sub post_process {
     return;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -55,7 +56,7 @@ Arrayref of field names, whose valid values should be stashed.
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Plugin>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -65,3 +66,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
